--[[
  < ResourcesOnTop v1.0 Beta >
_________________________________
    Author: Spyro
Maintainer: Selfron
   License: All Rights Reserved
   Contact: Spyr  @ ArenaJunkies
            Spyro  @ WowInterface
            Spyro_ @ Curse/WowAce

]]--

local Addon = CreateFrame("Frame") -- Addon main frame

-- Event registration
Addon:SetScript("OnEvent", function(self, event, ...) return self[event](self, ...) end)
Addon:RegisterEvent("PLAYER_LOGIN")

-- xOffset()
-- Changes the horizontal offset of the anchor of a frame.
-- > Frame: Frame reference
-- > Offset: Vertical offset
local function xOffset(Frame, Offset)
	local P = { Frame:GetPoint() }
	Frame:SetPoint(P[1], P[2], P[3], Offset, P[5])
end

-- yOffset()
-- Changes the vertical offset of the anchor of a frame.
-- > Frame: Frame reference
-- > Offset: Vertical offset
local function yOffset(Frame, Offset)
	local P = { Frame:GetPoint() }
	Frame:SetPoint(P[1], P[2], P[3], P[4], Offset)
end

-- yInvertTexture()
-- Inverts a texture vertically.
-- > Texture: Texture reference
local function yInvertTexture(Texture)
	local Left, Top, _, Bottom, Right = Texture:GetTexCoord()
	Texture:SetTexCoord(Left, Right, Bottom, Top) -- Swapping parameters 3 & 4 (top & bottom)
end

-- yInvertAllTextures()
-- Inverts vertically all the child textures of a frame.
-- > Frame: Frame reference
local function yInvertAllTextures(Frame)
	for _, Region in pairs({ Frame:GetRegions() }) do
		if Region:GetObjectType() == "Texture" then yInvertTexture(Region) end
	end
end

-- Event PLAYER_LOGIN
-- Fires after PLAYER_ENTERING_WORLD after logging in and after /reloadui.
function Addon:PLAYER_LOGIN()
	local class = UnitClass("player")

        -- Alternate Mana Bar
        if(class == "Priest" or class == "Shaman" or class == "Druid") then
                yInvertAllTextures(PlayerFrameAlternateManaBar)
		yOffset(PlayerFrameAlternateManaBar, 79)
                xOffset(PlayerFrameAlternateManaBar, 112)
                yOffset(PlayerFrameAlternateManaBarBorder, 3)
	end
        
        -- Rogue/Cat Combo Points
        if(class == "Rogue" or class == "Druid") then
		yOffset(ComboPointPlayerFrame.Combo1, 60)
		yOffset(ComboPointPlayerFrame.Background, 55)
		yInvertAllTextures(ComboPointPlayerFrame)
	end

        -- Paladin Holy Power
	if(class == "Paladin") then
		yOffset(PaladinPowerBarFrame, 111)
		yOffset(PaladinPowerBarFrameRune1, -5)
		yOffset(PaladinPowerBarFrameRune4, 3)
		yOffset(PaladinPowerBarFrameRune5, 3)
                yOffset(PaladinPowerBarFrameBankBG, 7)
		yInvertAllTextures(PaladinPowerBarFrame)
		yInvertTexture(PaladinPowerBarFrameGlowBGTexture)
		for i = 1, 5 do yInvertTexture(_G["PaladinPowerBarFrameRune"..i.."Texture"]) end
	end
	
	-- Warlock Shards
	if(class == "Warlock") then
		yOffset(WarlockPowerFrame, 102)
                xOffset(WarlockPowerFrame, 48)
		for i = 1, 5 do
			yInvertAllTextures(_G["WarlockPowerFrameShard"..i])
			yOffset(_G["WarlockPowerFrameShard"..i].shardFill, -5)
		end
	end

	-- DK Runes
	if(class == "Death Knight") then
		yOffset(RuneFrame, 99)
	end
	
        -- Monk Chi/Stagger
	if(class == "Monk") then
		if(class == "Monk") then	
			yOffset(MonkHarmonyBarFrame, 20)
			yInvertAllTextures(MonkHarmonyBarFrame)
			yOffset(MonkStaggerBar.LeftText, -4)
                        yOffset(MonkStaggerBar.RightText, -4)
			yInvertAllTextures(MonkStaggerBar)
                        yOffset(MonkStaggerBar, 83)
		end
	end
	
        -- Shaman Totems
	if(class == "Shaman" or class == "Warrior") then
		yOffset(TotemFrame, 130)
		for i = 1, 4 do
			yOffset(_G["TotemFrameTotem"..i.."Duration"], 44)
			yInvertTexture(select(2, _G["TotemFrameTotem"..i]:GetChildren()):GetRegions())
		end
	end
	
        -- Mage Arcane Charges/Runes
	if(class  == "Mage") then
                yOffset(MageArcaneChargesFrame, 110)
                yInvertAllTextures(MageArcaneChargesFrame)
                yOffset(MageArcaneChargesFrame.Background, -15)
                yOffset(_G["TotemFrameTotem1"], 120)
		xOffset(_G["TotemFrameTotem1"], 50)
		for i = 1, 2 do
			yOffset(_G["TotemFrameTotem"..i.."Duration"], 44)
			yInvertTexture(select(2, _G["TotemFrameTotem"..i]:GetChildren()):GetRegions())
		end
	end
end